coherence.upnp.devices.media_renderer_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.devices.media_renderer_client (module)

## `MediaRendererClient`

A class representing an media renderer client device.

class `MediaRendererClient`(device)

  Bases: `eventdispatcher.eventdispatcher.EventDispatcher`, `coherence.log.LogAble`

  Changed in version 0.9.0:

  - Introduced inheritance from EventDispatcher

  - The emitted events changed:

    > - Coherence.UPnP.DeviceClient.detection_completed => device_client_detection_completed

  - Changed class variable `detection_completed` to benefit from the EventDispatcher’s properties

  `logCategory` = 'mr_client'
  `detection_completed`

    To know whenever the device detection has completed. Defaults to False and it will be set automatically to True by the class method `service_notified()`.

  `remove`()
  `service_notified`(service)
  `state_variable_change`(variable)